package com.ruoyi.jarvis.mapper;

import com.ruoyi.jarvis.domain.JDOrder;
import java.util.List;

/**
 * 京东订单信息表 Mapper 接口
 */
public interface JDOrderMapper {

    /**
     * 查询京东订单列表
     */
    List<JDOrder> selectJDOrderList(JDOrder jdOrder);

    /**
     * 查询京东订单列表（支持动态排序）
     */
    List<JDOrder> selectJDOrderListWithSort(JDOrder jdOrder);

    /**
     * 根据主键查询
     */
    JDOrder selectJDOrderById(Long id);

    int insertJDOrder(JDOrder jdOrder);

    int updateJDOrder(JDOrder jdOrder);

    JDOrder selectJDOrderByRemark(String remark);

    List<JDOrder> selectJDOrderListByAddress(String address);

    /**
     * 根据订单号查询订单
     */
    JDOrder selectJDOrderByOrderId(String orderId);

    /**
     * 根据物流链接查询订单
     */
    JDOrder selectJDOrderByLogisticsLink(String logisticsLink);

    /**
     * 批量删除（根据主键ID）
     */
    int deleteJDOrderByIds(Long[] ids);
    
    /**
     * 查询分销标记为F或PDD且有物流链接的订单列表
     * @return 订单列表
     */
    List<JDOrder> selectJDOrderListByDistributionMarkFOrPDD();
}


